@@ -8,22 +8,23 @@
  * @version    @version@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2010, Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
 
 /**
  * Include some files
  */
-require_once("inc.DBAccess.php");
 require_once("inc.AccessUtils.php");
 require_once("inc.FileUtils.php");
 require_once("inc.ClassAccess.php");
+require_once("inc.ClassObject.php");
 require_once("inc.ClassFolder.php");
 require_once("inc.ClassDocument.php");
 require_once("inc.ClassGroup.php");
 require_once("inc.ClassUser.php");
 require_once("inc.ClassKeywords.php");
 require_once("inc.ClassNotification.php");
+require_once("inc.ClassAttribute.php");
 
 /**
  * Class to represent the complete document management system.
@@ -68,7 +69,7 @@ require_once("inc.ClassNotification.php");
  * @version    @version@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2010, Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
 class LetoDMS_Core_DMS {
 	/**
@@ -182,9 +183,9 @@ class LetoDMS_Core_DMS {
 		$this->enableAdminRevApp = false;
 		$this->enableConverting = false;
 		$this->convertFileTypes = array();
-		$this->version = '3.3.9';
+		$this->version = '3.4.2';
 		if($this->version[0] == '@')
-			$this->version = '3.3.9';
+			$this->version = '3.4.2';
 	} /* }}} */
 
 	function getDB() { /* {{{ */
@@ -383,6 +384,33 @@ class LetoDMS_Core_DMS {
 		return $documents;
 	} /* }}} */
 
+	/**
+	 * Returns all documents locked by a given user
+	 * FIXME: Not full implemented. Do not use, because it still requires the
+	 * temporary tables!
+	 *
+	 * @param object $user
+	 * @return array list of documents
+	 */
+	function getDocumentsLockedByUser($user) { /* {{{ */
+		$queryStr = "SELECT `tblDocuments`.* ".
+			"FROM `tblDocuments` LEFT JOIN `tblDocumentLocks` ON `tblDocuments`.`id` = `tblDocumentLocks`.`document` ".
+			"WHERE `tblDocumentLocks`.`userID` = '".$user->getID()."' ".
+			"ORDER BY `id` DESC";
+
+		$resArr = $this->db->getResultArray($queryStr);
+		if (is_bool($resArr) && !$resArr)
+			return false;
+
+		$documents = array();
+		foreach ($resArr as $row) {
+			$document = new LetoDMS_Core_Document($row["id"], $row["name"], $row["comment"], $row["date"], $row["expires"], $row["owner"], $row["folder"], $row["inheritAccess"], $row["defaultAccess"], $row["lockUser"], $row["keywords"], $row["sequence"]);
+			$document->setDMS($this);
+			$documents[] = $document;
+		}
+		return $documents;
+	} /* }}} */
+
 	/**
 	 * Returns a document by its name
 	 *
@@ -417,9 +445,49 @@ class LetoDMS_Core_DMS {
 		return $document;
 	} /* }}} */
 
+	function makeTimeStamp($hour, $min, $sec, $year, $month, $day) {
+		$thirtyone = array (1, 3, 5, 7, 8, 10, 12);
+		$thirty = array (4, 6, 9, 11);
+
+		// Very basic check that the terms are valid. Does not fail for illegal
+		// dates such as 31 Feb.
+		if (!is_numeric($hour) || !is_numeric($min) || !is_numeric($sec) || !is_numeric($year) || !is_numeric($month) || !is_numeric($day) || $month<1 || $month>12 || $day<1 || $day>31 || $hour<0 || $hour>23 || $min<0 || $min>59 || $sec<0 || $sec>59) {
+			return false;
+		}
+		$year = (int) $year;
+		$month = (int) $month;
+		$day = (int) $day;
+
+		if (array_search($month, $thirtyone)) {
+			$max=31;
+		}
+		else if (array_search($month, $thirty)) {
+			$max=30;
+		}
+		else {
+			$max=(($year % 4 == 0) && ($year % 100 != 0 || $year % 400 == 0)) ? 29 : 28;
+		}
+
+		// If the date falls out of bounds, set it to the maximum for the given
+		// month. Makes assumption about the user's intention, rather than failing
+		// for absolutely everything.
+		if ($day>$max) {
+			$day=$max;
+		}
+
+		return mktime($hour, $min, $sec, $month, $day, $year);
+	}
+
 	/*
 	 * Search the database for documents
 	 *
+	 * Note: the creation date will be used to check againts the
+	 * date saved with the document
+	 * or folder. The modification date will only be used for documents. It
+	 * is checked against the creation date of the document content. This
+	 * meanѕ that updateѕ of a document will only result in a searchable
+	 * modification if a new version is uploaded.
+	 *
 	 * @param query string seach query with space separated words
 	 * @param limit integer number of items in result set
 	 * @param offset integer index of first item in result set
@@ -431,14 +499,17 @@ class LetoDMS_Core_DMS {
 	 * @param status array list of status
 	 * @param creationstartdate array search for documents created after this date
 	 * @param creationenddate array search for documents created before this date
+	 * @param modificationstartdate array search for documents modified after this date
+	 * @param modificationenddate array search for documents modified before this date
 	 * @param categories array list of categories the documents must have assigned
+	 * @param attributes array list of attributes
 	 * @param mode int decide whether to search for documents/folders
 	 *        0x1 = documents only
 	 *        0x2 = folders only
 	 *        0x3 = both
 	 * @return array containing the elements total and docs
 	 */
-	function search($query, $limit=0, $offset=0, $logicalmode='AND', $searchin=array(), $startFolder=null, $owner=null, $status = array(), $creationstartdate=array(), $creationenddate=array(), $categories=array(), $mode=0x3) { /* {{{ */
+	function search($query, $limit=0, $offset=0, $logicalmode='AND', $searchin=array(), $startFolder=null, $owner=null, $status = array(), $creationstartdate=array(), $creationenddate=array(), $modificationstartdate=array(), $modificationenddate=array(), $categories=array(), $attributes=array(), $mode=0x3) { /* {{{ */
 		// Split the search string into constituent keywords.
 		$tkeys=array();
 		if (strlen($query)>0) {
@@ -447,27 +518,26 @@ class LetoDMS_Core_DMS {
 
 		// if none is checkd search all
 		if (count($searchin)==0)
-			$searchin=array( 0, 1, 2, 3);
+			$searchin=array( 0, 1, 2, 3, 4);
 
 		/*--------- Do it all over again for folders -------------*/
 		if($mode & 0x2) {
 			$searchKey = "";
-			// Assemble the arguments for the concatenation function. This allows the
-			// search to be carried across all the relevant fields.
-			$concatFunction = "";
 			if (in_array(2, $searchin)) {
-				$concatFunction = (strlen($concatFunction) == 0 ? "" : $concatFunction.", ")."`tblFolders`.`name`";
+				$searchFields[] = "`tblFolders`.`name`";
 			}
 			if (in_array(3, $searchin)) {
-				$concatFunction = (strlen($concatFunction) == 0 ? "" : $concatFunction.", ")."`tblFolders`.`comment`";
+				$searchFields[] = "`tblFolders`.`comment`";
+			}
+			if (in_array(4, $searchin)) {
+				$searchFields[] = "`tblFolderAttributes`.`value`";
 			}
 
-			if (strlen($concatFunction)>0 && count($tkeys)>0) {
-				$concatFunction = "CONCAT_WS(' ', ".$concatFunction.")";
+			if (count($searchFields)>0) {
 				foreach ($tkeys as $key) {
 					$key = trim($key);
 					if (strlen($key)>0) {
-						$searchKey = (strlen($searchKey)==0 ? "" : $searchKey." ".$logicalmode." ").$concatFunction." LIKE ".$this->db->qstr('%'.$key.'%');
+						$searchKey = (strlen($searchKey)==0 ? "" : $searchKey." ".$logicalmode." ")."(".implode(" like ".$this->db->qstr("%".$key."%")." OR ", $searchFields)." like ".$this->db->qstr("%".$key."%").")";
 					}
 				}
 			}
@@ -489,13 +559,13 @@ class LetoDMS_Core_DMS {
 			// Is the search restricted to documents created between two specific dates?
 			$searchCreateDate = "";
 			if ($creationstartdate) {
-				$startdate = makeTimeStamp(0, 0, 0, $creationstartdate['year'], $creationstartdate["month"], $creationstartdate["day"]);
+				$startdate = LetoDMS_Core_DMS::makeTimeStamp($creationstartdate['hour'], $creationstartdate['minute'], $creationstartdate['second'], $creationstartdate['year'], $creationstartdate["month"], $creationstartdate["day"]);
 				if ($startdate) {
 					$searchCreateDate .= "`tblFolders`.`date` >= ".$startdate;
 				}
 			}
 			if ($creationenddate) {
-				$stopdate = makeTimeStamp(23, 59, 59, $creationenddate["year"], $creationenddate["month"], $creationenddate["day"]);
+				$stopdate = LetoDMS_Core_DMS::makeTimeStamp($creationenddate['hour'], $creationstartdate['minute'], $creationstartdate['second'], $creationenddate["year"], $creationenddate["month"], $creationenddate["day"]);
 				if ($stopdate) {
 					if($startdate)
 						$searchCreateDate .= " AND ";
@@ -503,7 +573,7 @@ class LetoDMS_Core_DMS {
 				}
 			}
 
-			$searchQuery = "FROM `tblFolders` WHERE 1=1";
+			$searchQuery = "FROM `tblFolders` LEFT JOIN `tblFolderAttributes` on `tblFolders`.`id`=`tblFolderAttributes`.`folder` WHERE 1=1";
 
 			if (strlen($searchKey)>0) {
 				$searchQuery .= " AND (".$searchKey.")";
@@ -518,41 +588,48 @@ class LetoDMS_Core_DMS {
 				$searchQuery .= " AND (".$searchCreateDate.")";
 			}
 
-			// Count the number of rows that the search will produce.
-			$resArr = $this->db->getResultArray("SELECT COUNT(*) AS num ".$searchQuery);
-			$totalFolders = 0;
-			if (is_numeric($resArr[0]["num"]) && $resArr[0]["num"]>0) {
-				$totalFolders = (integer)$resArr[0]["num"];
-			}
-
-			// If there are no results from the count query, then there is no real need
-			// to run the full query. TODO: re-structure code to by-pass additional
-			// queries when no initial results are found.
-
-			// Only search if the offset is not beyond the number of folders
-			if($totalFolders > $offset) {
-				// Prepare the complete search query, including the LIMIT clause.
-				$searchQuery = "SELECT `tblFolders`.* ".$searchQuery;
-
-				if($limit) {
-					$searchQuery .= " LIMIT ".$offset.",".$limit;
+			/* Do not search for folders if not at least a search for a key,
+			 * an owner, or creation date is requested.
+			 */
+			if($searchKey || $searchOwner || $searchCreateDate) {
+				// Count the number of rows that the search will produce.
+				$resArr = $this->db->getResultArray("SELECT COUNT(*) AS num ".$searchQuery." GROUP BY `tblFolders`.`id`");
+				$totalFolders = 0;
+				if ($resArr && isset($resArr[0]) && is_numeric($resArr[0]["num"]) && $resArr[0]["num"]>0) {
+					$totalFolders = (integer)$resArr[0]["num"];
 				}
 
-				// Send the complete search query to the database.
-				$resArr = $this->db->getResultArray($searchQuery);
-			} else {
-				$resArr = array();
-			}
+				// If there are no results from the count query, then there is no real need
+				// to run the full query. TODO: re-structure code to by-pass additional
+				// queries when no initial results are found.
 
-			// ------------------- Ausgabe der Ergebnisse ----------------------------
-			$numResults = count($resArr);
-			if ($numResults == 0) {
-				$folderresult = array('totalFolders'=>$totalFolders, 'folders'=>array());
-			} else {
-				foreach ($resArr as $folderArr) {
-					$folders[] = $this->getFolder($folderArr['id']);
+				// Only search if the offset is not beyond the number of folders
+				if($totalFolders > $offset) {
+					// Prepare the complete search query, including the LIMIT clause.
+					$searchQuery = "SELECT DISTINCT `tblFolders`.* ".$searchQuery;
+
+					if($limit) {
+						$searchQuery .= " LIMIT ".$offset.",".$limit;
+					}
+
+					// Send the complete search query to the database.
+					$resArr = $this->db->getResultArray($searchQuery);
+				} else {
+					$resArr = array();
 				}
-				$folderresult = array('totalFolders'=>$totalFolders, 'folders'=>$folders);
+
+				// ------------------- Ausgabe der Ergebnisse ----------------------------
+				$numResults = count($resArr);
+				if ($numResults == 0) {
+					$folderresult = array('totalFolders'=>$totalFolders, 'folders'=>array());
+				} else {
+					foreach ($resArr as $folderArr) {
+						$folders[] = $this->getFolder($folderArr['id']);
+					}
+					$folderresult = array('totalFolders'=>$totalFolders, 'folders'=>$folders);
+				}
+			} else {
+				$folderresult = array('totalFolders'=>0, 'folders'=>array());
 			}
 		} else {
 			$folderresult = array('totalFolders'=>0, 'folders'=>array());
@@ -562,25 +639,27 @@ class LetoDMS_Core_DMS {
 
 		if($mode & 0x1) {
 			$searchKey = "";
-			// Assemble the arguments for the concatenation function. This allows the
-			// search to be carried across all the relevant fields.
-			$concatFunction = "";
+			$searchFields = array();
 			if (in_array(1, $searchin)) {
-				$concatFunction = "`tblDocuments`.`keywords`";
+				$searchFields[] = "`tblDocuments`.`keywords`";
 			}
 			if (in_array(2, $searchin)) {
-				$concatFunction = (strlen($concatFunction) == 0 ? "" : $concatFunction.", ")."`tblDocuments`.`name`";
+				$searchFields[] = "`tblDocuments`.`name`";
 			}
 			if (in_array(3, $searchin)) {
-				$concatFunction = (strlen($concatFunction) == 0 ? "" : $concatFunction.", ")."`tblDocuments`.`comment`";
+				$searchFields[] = "`tblDocuments`.`comment`";
+			}
+			if (in_array(4, $searchin)) {
+				$searchFields[] = "`tblDocumentAttributes`.`value`";
+				$searchFields[] = "`tblDocumentContentAttributes`.`value`";
 			}
 
-			if (strlen($concatFunction)>0 && count($tkeys)>0) {
-				$concatFunction = "CONCAT_WS(' ', ".$concatFunction.")";
+
+			if (count($searchFields)>0) {
 				foreach ($tkeys as $key) {
 					$key = trim($key);
 					if (strlen($key)>0) {
-						$searchKey = (strlen($searchKey)==0 ? "" : $searchKey." ".$logicalmode." ").$concatFunction." LIKE ".$this->db->qstr('%'.$key.'%');
+						$searchKey = (strlen($searchKey)==0 ? "" : $searchKey." ".$logicalmode." ")."(".implode(" like ".$this->db->qstr("%".$key."%")." OR ", $searchFields)." like ".$this->db->qstr("%".$key."%").")";
 					}
 				}
 			}
@@ -609,22 +688,60 @@ class LetoDMS_Core_DMS {
 				$searchCategories = "`tblDocumentCategory`.`categoryID` in (".implode(',', $catids).")";
 			}
 
+			// Check to see if the search has been restricted to a particular
+			// attribute.
+			$searchAttributes = array();
+			if ($attributes) {
+				foreach($attributes as $attrdefid=>$attribute) {
+					if($attribute) {
+						$attrdef = $this->getAttributeDefinition($attrdefid);
+						if($attrdef->getObjType() == LetoDMS_Core_AttributeDefinition::objtype_document) {
+							if($attrdef->getValueSet())
+								$searchAttributes[] = "`tblDocumentAttributes`.`attrdef`=".$attrdefid." AND `tblDocumentAttributes`.`value`='".$attribute."'";
+							else
+								$searchAttributes[] = "`tblDocumentAttributes`.`attrdef`=".$attrdefid." AND `tblDocumentAttributes`.`value` like '%".$attribute."%'";
+						} elseif($attrdef->getObjType() == LetoDMS_Core_AttributeDefinition::objtype_documentcontent) {
+							if($attrdef->getValueSet())
+								$searchAttributes[] = "`tblDocumentContentAttributes`.`attrdef`=".$attrdefid." AND `tblDocumentContentAttributes`.`value`='".$attribute."'";
+							else
+								$searchAttributes[] = "`tblDocumentContentAttributes`.`attrdef`=".$attrdefid." AND `tblDocumentContentAttributes`.`value` like '%".$attribute."%'";
+						}
+					}
+				}
+			}
+
 			// Is the search restricted to documents created between two specific dates?
 			$searchCreateDate = "";
 			if ($creationstartdate) {
-				$startdate = makeTimeStamp(0, 0, 0, $creationstartdate['year'], $creationstartdate["month"], $creationstartdate["day"]);
+				$startdate = LetoDMS_Core_DMS::makeTimeStamp($creationstartdate['hour'], $creationstartdate['minute'], $creationstartdate['second'], $creationstartdate['year'], $creationstartdate["month"], $creationstartdate["day"]);
 				if ($startdate) {
 					$searchCreateDate .= "`tblDocuments`.`date` >= ".$startdate;
 				}
 			}
 			if ($creationenddate) {
-				$stopdate = makeTimeStamp(23, 59, 59, $creationenddate["year"], $creationenddate["month"], $creationenddate["day"]);
+				$stopdate = LetoDMS_Core_DMS::makeTimeStamp($creationenddate['hour'], $creationenddate['minute'], $creationenddate['second'], $creationenddate["year"], $creationenddate["month"], $creationenddate["day"]);
 				if ($stopdate) {
-					if($startdate)
+					if($searchCreateDate)
 						$searchCreateDate .= " AND ";
 					$searchCreateDate .= "`tblDocuments`.`date` <= ".$stopdate;
 				}
 			}
+			if ($modificationstartdate) {
+				$startdate = LetoDMS_Core_DMS::makeTimeStamp($modificationstartdate['hour'], $modificationstartdate['minute'], $modificationstartdate['second'], $modificationstartdate['year'], $modificationstartdate["month"], $modificationstartdate["day"]);
+				if ($startdate) {
+					if($searchCreateDate)
+						$searchCreateDate .= " AND ";
+					$searchCreateDate .= "`tblDocumentContent`.`date` >= ".$startdate;
+				}
+			}
+			if ($modificationenddate) {
+				$stopdate = LetoDMS_Core_DMS::makeTimeStamp($modificationenddate['hour'], $modificationenddate['minute'], $modificationenddate['second'], $modificationenddate["year"], $modificationenddate["month"], $modificationenddate["day"]);
+				if ($stopdate) {
+					if($searchCreateDate)
+						$searchCreateDate .= " AND ";
+					$searchCreateDate .= "`tblDocumentContent`.`date` <= ".$stopdate;
+				}
+			}
 
 			// ---------------------- Suche starten ----------------------------------
 
@@ -638,6 +755,8 @@ class LetoDMS_Core_DMS {
 
 			$searchQuery = "FROM `tblDocumentContent` ".
 				"LEFT JOIN `tblDocuments` ON `tblDocuments`.`id` = `tblDocumentContent`.`document` ".
+				"LEFT JOIN `tblDocumentAttributes` ON `tblDocuments`.`id` = `tblDocumentAttributes`.`document` ".
+				"LEFT JOIN `tblDocumentContentAttributes` ON `tblDocumentContent`.`id` = `tblDocumentContentAttributes`.`content` ".
 				"LEFT JOIN `tblDocumentStatus` ON `tblDocumentStatus`.`documentID` = `tblDocumentContent`.`document` ".
 				"LEFT JOIN `tblDocumentStatusLog` ON `tblDocumentStatusLog`.`statusID` = `tblDocumentStatus`.`statusID` ".
 				"LEFT JOIN `ttstatid` ON `ttstatid`.`maxLogID` = `tblDocumentStatusLog`.`statusLogID` ".
@@ -662,6 +781,9 @@ class LetoDMS_Core_DMS {
 			if (strlen($searchCreateDate)>0) {
 				$searchQuery .= " AND (".$searchCreateDate.")";
 			}
+			if ($searchAttributes) {
+				$searchQuery .= " AND (".implode(" AND ", $searchAttributes).")";
+			}
 
 			// status
 			if ($status) {
@@ -669,7 +791,7 @@ class LetoDMS_Core_DMS {
 			}
 
 			// Count the number of rows that the search will produce.
-			$resArr = $this->db->getResultArray("SELECT COUNT(*) AS num ".$searchQuery);
+			$resArr = $this->db->getResultArray("SELECT COUNT(*) AS num ".$searchQuery." GROUP BY `tblDocuments`.`id`");
 			$totalDocs = 0;
 			if (is_numeric($resArr[0]["num"]) && $resArr[0]["num"]>0) {
 				$totalDocs = (integer)$resArr[0]["num"];
@@ -680,7 +802,7 @@ class LetoDMS_Core_DMS {
 			// queries when no initial results are found.
 
 			// Prepare the complete search query, including the LIMIT clause.
-			$searchQuery = "SELECT `tblDocuments`.*, ".
+			$searchQuery = "SELECT DISTINCT `tblDocuments`.*, ".
 				"`tblDocumentContent`.`version`, ".
 				"`tblDocumentStatusLog`.`status`, `tblDocumentLocks`.`userID` as `lockUser` ".$searchQuery;
 
@@ -805,7 +927,7 @@ class LetoDMS_Core_DMS {
 
 		$resArr = $resArr[0];
 
-		$user = new LetoDMS_Core_User($resArr["id"], $resArr["login"], $resArr["pwd"], $resArr["fullName"], $resArr["email"], $resArr["language"], $resArr["theme"], $resArr["comment"], $resArr["role"], $resArr["hidden"]);
+		$user = new LetoDMS_Core_User($resArr["id"], $resArr["login"], $resArr["pwd"], $resArr["fullName"], $resArr["email"], $resArr["language"], $resArr["theme"], $resArr["comment"], $resArr["role"], $resArr["hidden"], $resArr["disabled"], $resArr["pwdExpiration"], $resArr["loginfailures"]);
 		$user->setDMS($this);
 		return $user;
 	} /* }}} */
@@ -832,7 +954,7 @@ class LetoDMS_Core_DMS {
 
 		$resArr = $resArr[0];
 
-		$user = new LetoDMS_Core_User($resArr["id"], $resArr["login"], $resArr["pwd"], $resArr["fullName"], $resArr["email"], $resArr["language"], $resArr["theme"], $resArr["comment"], $resArr["role"], $resArr["hidden"]);
+		$user = new LetoDMS_Core_User($resArr["id"], $resArr["login"], $resArr["pwd"], $resArr["fullName"], $resArr["email"], $resArr["language"], $resArr["theme"], $resArr["comment"], $resArr["role"], $resArr["hidden"], $resArr["disabled"], $resArr["pwdExpiration"], $resArr["loginfailures"]);
 		$user->setDMS($this);
 		return $user;
 	} /* }}} */
@@ -855,7 +977,7 @@ class LetoDMS_Core_DMS {
 
 		$resArr = $resArr[0];
 
-		$user = new LetoDMS_Core_User($resArr["id"], $resArr["login"], $resArr["pwd"], $resArr["fullName"], $resArr["email"], $resArr["language"], $resArr["theme"], $resArr["comment"], $resArr["role"], $resArr["hidden"]);
+		$user = new LetoDMS_Core_User($resArr["id"], $resArr["login"], $resArr["pwd"], $resArr["fullName"], $resArr["email"], $resArr["language"], $resArr["theme"], $resArr["comment"], $resArr["role"], $resArr["hidden"], $resArr["disabled"], $resArr["pwdExpiration"], $resArr["loginfailures"]);
 		$user->setDMS($this);
 		return $user;
 	} /* }}} */
@@ -865,8 +987,11 @@ class LetoDMS_Core_DMS {
 	 *
 	 * @return array of instances of LetoDMS_Core_User or false
 	 */
-	function getAllUsers() { /* {{{ */
-		$queryStr = "SELECT * FROM tblUsers ORDER BY login";
+	function getAllUsers($orderby = '') { /* {{{ */
+		if($orderby == 'fullname')
+			$queryStr = "SELECT * FROM tblUsers ORDER BY fullname";
+		else
+			$queryStr = "SELECT * FROM tblUsers ORDER BY login";
 		$resArr = $this->db->getResultArray($queryStr);
 
 		if (is_bool($resArr) && $resArr == false)
@@ -875,7 +1000,7 @@ class LetoDMS_Core_DMS {
 		$users = array();
 
 		for ($i = 0; $i < count($resArr); $i++) {
-			$user = new LetoDMS_Core_User($resArr[$i]["id"], $resArr[$i]["login"], $resArr[$i]["pwd"], $resArr[$i]["fullName"], $resArr[$i]["email"], (isset($resArr["language"])?$resArr["language"]:NULL), (isset($resArr["theme"])?$resArr["theme"]:NULL), $resArr[$i]["comment"], $resArr[$i]["role"], $resArr[$i]["hidden"]);
+			$user = new LetoDMS_Core_User($resArr[$i]["id"], $resArr[$i]["login"], $resArr[$i]["pwd"], $resArr[$i]["fullName"], $resArr[$i]["email"], (isset($resArr["language"])?$resArr["language"]:NULL), (isset($resArr["theme"])?$resArr["theme"]:NULL), $resArr[$i]["comment"], $resArr[$i]["role"], $resArr[$i]["hidden"], $resArr[$i]["disabled"], $resArr[$i]["pwdExpiration"], $resArr[$i]["loginfailures"]);
 			$user->setDMS($this);
 			$users[$i] = $user;
 		}
@@ -894,16 +1019,17 @@ class LetoDMS_Core_DMS {
 	 * @param integer $role role of new user (can be 0=normal, 1=admin, 2=guest)
 	 * @param integer $isHidden hide user in all lists, if this is set login
 	 *        is still allowed
+	 * @param integer $isDisabled disable user and prevent login
 	 * @return object of LetoDMS_Core_User
 	 */
-	function addUser($login, $pwd, $fullName, $email, $language, $theme, $comment, $role='0', $isHidden=0) { /* {{{ */
+	function addUser($login, $pwd, $fullName, $email, $language, $theme, $comment, $role='0', $isHidden=0, $isDisabled=0, $pwdexpiration='') { /* {{{ */
 		$db = $this->db;
 		if (is_object($this->getUserByLogin($login))) {
 			return false;
 		}
 		if($role == '')
 			$role = '0';
-		$queryStr = "INSERT INTO tblUsers (login, pwd, fullName, email, language, theme, comment, role, hidden) VALUES (".$db->qstr($login).", ".$db->qstr($pwd).", ".$db->qstr($fullName).", ".$db->qstr($email).", '".$language."', '".$theme."', ".$db->qstr($comment).", '".intval($role)."', '".intval($isHidden)."')";
+		$queryStr = "INSERT INTO tblUsers (login, pwd, fullName, email, language, theme, comment, role, hidden, disabled, pwdExpiration) VALUES (".$db->qstr($login).", ".$db->qstr($pwd).", ".$db->qstr($fullName).", ".$db->qstr($email).", '".$language."', '".$theme."', ".$db->qstr($comment).", '".intval($role)."', '".intval($isHidden)."', '".intval($isDisabled)."', ".$db->qstr($pwdexpiration).")";
 		$res = $this->db->getResult($queryStr);
 		if (!$res)
 			return false;
@@ -1139,7 +1265,7 @@ class LetoDMS_Core_DMS {
 		if (is_object($this->getDocumentCategoryByName($name))) {
 			return false;
 		}
-		$queryStr = "INSERT INTO tblCategory (name) VALUES (".$this->db-qstr($name).")";
+		$queryStr = "INSERT INTO tblCategory (name) VALUES (".$this->db->qstr($name).")";
 		if (!$this->db->getResult($queryStr))
 			return false;
 
@@ -1251,6 +1377,111 @@ class LetoDMS_Core_DMS {
 		if (!$this->db->getResult($queryStr))
 			return false;
 		return true;
-	}
+	} /* }}} */
+
+	/**
+	 * Return a attribute definition by its id
+	 *
+	 * This function retrieves a attribute definitionr from the database by
+	 * its id.
+	 *
+	 * @param integer $id internal id of attribute defintion
+	 * @return object instance of LetoDMS_Core_AttributeDefinition or false
+	 */
+	function getAttributeDefinition($id) { /* {{{ */
+		if (!is_numeric($id))
+			return false;
+
+		$queryStr = "SELECT * FROM tblAttributeDefinitions WHERE id = " . (int) $id;
+		$resArr = $this->db->getResultArray($queryStr);
+
+		if (is_bool($resArr) && $resArr == false) return false;
+		if (count($resArr) != 1) return false;
+
+		$resArr = $resArr[0];
+
+		$attrdef = new LetoDMS_Core_AttributeDefinition($resArr["id"], $resArr["name"], $resArr["objtype"], $resArr["type"], $resArr["multiple"], $resArr["minvalues"], $resArr["maxvalues"], $resArr["valueset"]);
+		$attrdef->setDMS($this);
+		return $attrdef;
+	} /* }}} */
+
+	/**
+	 * Return a attribute definition by its name
+	 *
+	 * This function retrieves an attribute def. from the database by its name.
+	 *
+	 * @param string $name internal name of attribute def.
+	 * @return object instance of LetoDMS_Core_AttributeDefinition or false
+	 */
+	function getAttributeDefinitionByName($name) { /* {{{ */
+		$queryStr = "SELECT * FROM tblAttributeDefinitions WHERE name = " . $this->db->qstr($name);
+		$resArr = $this->db->getResultArray($queryStr);
+
+		if (is_bool($resArr) && $resArr == false) return false;
+		if (count($resArr) != 1) return false;
+
+		$resArr = $resArr[0];
+
+		$attrdef = new LetoDMS_Core_AttributeDefinition($resArr["id"], $resArr["name"], $resArr["objtype"], $resArr["type"], $resArr["multiple"], $resArr["minvalues"], $resArr["maxvalues"], $resArr["valueset"]);
+		$attrdef->setDMS($this);
+		return $attrdef;
+	} /* }}} */
+
+	/**
+	 * Return list of all attributes definitions
+	 *
+	 * @param integer $objtype select those attributes defined for an object type
+	 * @return array of instances of LetoDMS_Core_AttributeDefinition or false
+	 */
+	function getAllAttributeDefinitions($objtype=0) { /* {{{ */
+		$queryStr = "SELECT * FROM tblAttributeDefinitions";
+		if($objtype) {
+			if(is_array($objtype))
+				$queryStr .= ' WHERE objtype in (\''.implode("','", $objtype).'\')';
+			else
+				$queryStr .= ' WHERE objtype='.intval($objtype);
+		}
+		$queryStr .= ' ORDER BY name';
+		$resArr = $this->db->getResultArray($queryStr);
+
+		if (is_bool($resArr) && $resArr == false)
+			return false;
+
+		$attrdefs = array();
+
+		for ($i = 0; $i < count($resArr); $i++) {
+			$attrdef = new LetoDMS_Core_AttributeDefinition($resArr[$i]["id"], $resArr[$i]["name"], $resArr[$i]["objtype"], $resArr[$i]["type"], $resArr[$i]["multiple"], $resArr[$i]["minvalues"], $resArr[$i]["maxvalues"], $resArr[$i]["valueset"]);
+			$attrdef->setDMS($this);
+			$attrdefs[$i] = $attrdef;
+		}
+
+		return $attrdefs;
+	} /* }}} */
+
+	/**
+	 * Add a new attribute definition
+	 *
+	 * @param string $name name of attribute
+	 * @param string $type type of attribute
+	 * @param boolean $multiple set to 1 if attribute has multiple attributes
+	 * @param integer $minvalues minimum number of values
+	 * @param integer $maxvalues maximum number of values if multiple is set
+	 * @param string $valueset list of allowed values (csv format)
+	 * @return object of LetoDMS_Core_User
+	 */
+	function addAttributeDefinition($name, $objtype, $type, $multiple=0, $minvalues=0, $maxvalues=1, $valueset='') { /* {{{ */
+		if (is_object($this->getAttributeDefinitionByName($name))) {
+			return false;
+		}
+		if(!$type)
+			return false;
+		$queryStr = "INSERT INTO tblAttributeDefinitions (name, objtype, type, multiple, minvalues, maxvalues, valueset) VALUES (".$this->db->qstr($name).", ".intval($objtype).", ".intval($type).", ".intval($multiple).", ".intval($minvalues).", ".intval($maxvalues).", ".$this->db->qstr($valueset).")";
+		$res = $this->db->getResult($queryStr);
+		if (!$res)
+			return false;
+
+		return $this->getAttributeDefinition($this->db->getInsertID());
+	} /* }}} */
+
 }
 ?>
