@@ -9,7 +9,7 @@
  *             Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Matteo Lucarelli, 2010 Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
 
 /**
@@ -41,14 +41,9 @@ define("S_EXPIRED",  -3);
  *             Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Matteo Lucarelli, 2010 Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
-class LetoDMS_Core_Document { /* {{{ */
-	/**
-	 * @var integer unique id of document
-	 */
-	var $_id;
-
+class LetoDMS_Core_Document extends LetoDMS_Core_Object { /* {{{ */
 	/**
 	 * @var string name of document
 	 */
@@ -114,13 +109,8 @@ class LetoDMS_Core_Document { /* {{{ */
 	 */
 	var $_sequence;
 
-	/**
-	 * @var object back reference to document management system
-	 */
-	var $_dms;
-
 	function LetoDMS_Core_Document($id, $name, $comment, $date, $expires, $ownerID, $folderID, $inheritAccess, $defaultAccess, $locked, $keywords, $sequence) { /* {{{ */
-		$this->_id = $id;
+		parent::__construct($id);
 		$this->_name = $name;
 		$this->_comment = $comment;
 		$this->_date = $date;
@@ -134,21 +124,6 @@ class LetoDMS_Core_Document { /* {{{ */
 		$this->_sequence = $sequence;
 		$this->_categories = array();
 		$this->_notifyList = array();
-		$this->_dms = null;
-	} /* }}} */
-
-	/*
-	 * Set dms this document belongs to.
-	 *
-	 * Each document needs a reference to the dms it belongs to. It will be
-	 * set when the folder is created by LetoDMS::getDocument() or
-	 * LetoDMS::search(). The dms has a
-	 * references to the currently logged in user and the database connection.
-	 *
-	 * @param object $dms reference to dms
-	 */
-	function setDMS($dms) { /* {{{ */
-		$this->_dms = $dms;
 	} /* }}} */
 
 	/*
@@ -757,6 +732,9 @@ class LetoDMS_Core_Document { /* {{{ */
 	 * @return integer access mode
 	 */
 	function getAccessMode($user) { /* {{{ */
+		if(!$user)
+			return M_NONE;
+
 		/* Administrators have unrestricted access */
 		if ($user->isAdmin()) return M_ALL;
 
@@ -1064,15 +1042,17 @@ class LetoDMS_Core_Document { /* {{{ */
 	 * @param array $reviewers list of reviewers
 	 * @param array $approvers list of approvers
 	 * @param integer $version version number of content or 0 if next higher version shall be used.
+	 * @param array $attributes list of version attributes. The element key
+	 *        must be the id of the attribute definition.
 	 * @return bool/array false in case of an error or a result set
 	 */
-	function addContent($comment, $user, $tmpFile, $orgFileName, $fileType, $mimeType, $reviewers=array(), $approvers=array(), $version=0) { /* {{{ */
+	function addContent($comment, $user, $tmpFile, $orgFileName, $fileType, $mimeType, $reviewers=array(), $approvers=array(), $version=0, $attributes=array()) { /* {{{ */
 		$db = $this->_dms->getDB();
 
 		// the doc path is id/version.filetype
 		$dir = $this->getDir();
 
-		$date = mktime();
+		$date = time();
 
 		/* The version field in table tblDocumentContent used to be auto
 		 * increment but that requires the field to be primary as well if
@@ -1091,13 +1071,26 @@ class LetoDMS_Core_Document { /* {{{ */
 						"(".$this->_id.", ".(int)$version.",".$db->qstr($comment).", ".$date.", ".$user->getID().", ".$db->qstr($dir).", ".$db->qstr($orgFileName).", ".$db->qstr($fileType).", ".$db->qstr($mimeType).")";
 		if (!$db->getResult($queryStr)) return false;
 
+		$contentID = $db->getInsertID();
+
 		// copy file
 		if (!LetoDMS_Core_File::makeDir($this->_dms->contentDir . $dir)) return false;
 		if (!LetoDMS_Core_File::copyFile($tmpFile, $this->_dms->contentDir . $dir . $version . $fileType)) return false;
 
 		unset($this->_content);
 		unset($this->_latestContent);
-		$docResultSet = new LetoDMS_Core_AddContentResultSet(new LetoDMS_Core_DocumentContent($this, $version, $comment, $date, $user->getID(), $dir, $orgFileName, $fileType, $mimeType));
+		$content = new LetoDMS_Core_DocumentContent($contentID, $this, $version, $comment, $date, $user->getID(), $dir, $orgFileName, $fileType, $mimeType);
+		$docResultSet = new LetoDMS_Core_AddContentResultSet($content);
+
+		if($attributes) {
+			foreach($attributes as $attrdefid=>$attribute) {
+				if(trim($attribute))
+					if(!$content->setAttributeValue($this->_dms->getAttributeDefinition($attrdefid), $attribute)) {
+						$this->removeContent($content);
+						return false;
+					}
+			}
+		}
 
 		// TODO - verify
 		if ($this->_dms->enableConverting && in_array($docResultSet->_content->getFileType(), array_keys($this->_dms->convertFileTypes)))
@@ -1161,7 +1154,7 @@ class LetoDMS_Core_Document { /* {{{ */
 			$comment="";
 		}
 		$queryStr = "INSERT INTO `tblDocumentStatusLog` (`statusID`, `status`, `comment`, `date`, `userID`) ".
-			"VALUES ('". $statusID ."', '". $status."', 'New document content submitted". $comment ."', NOW(), '". $user->getID() ."')";
+			"VALUES ('". $statusID ."', '". $status."', 'New document content submitted". $comment ."', CURRENT_TIMESTAMP, '". $user->getID() ."')";
 		if (!$db->getResult($queryStr))
 			return false;
 
@@ -1188,7 +1181,7 @@ class LetoDMS_Core_Document { /* {{{ */
 
 			$this->_content = array();
 			foreach ($resArr as $row)
-				array_push($this->_content, new LetoDMS_Core_DocumentContent($this, $row["version"], $row["comment"], $row["date"], $row["createdBy"], $row["dir"], $row["orgFileName"], $row["fileType"], $row["mimeType"]));
+				array_push($this->_content, new LetoDMS_Core_DocumentContent($row["id"], $this, $row["version"], $row["comment"], $row["date"], $row["createdBy"], $row["dir"], $row["orgFileName"], $row["fileType"], $row["mimeType"]));
 		}
 
 		return $this->_content;
@@ -1220,7 +1213,7 @@ class LetoDMS_Core_Document { /* {{{ */
 			return false;
 
 		$resArr = $resArr[0];
-		return new LetoDMS_Core_DocumentContent($this, $resArr["version"], $resArr["comment"], $resArr["date"], $resArr["createdBy"], $resArr["dir"], $resArr["orgFileName"], $resArr["fileType"], $resArr["mimeType"]);
+		return new LetoDMS_Core_DocumentContent($resArr["id"], $this, $resArr["version"], $resArr["comment"], $resArr["date"], $resArr["createdBy"], $resArr["dir"], $resArr["orgFileName"], $resArr["fileType"], $resArr["mimeType"]);
 	} /* }}} */
 
 	function getLatestContent() { /* {{{ */
@@ -1234,7 +1227,7 @@ class LetoDMS_Core_Document { /* {{{ */
 				return false;
 
 			$resArr = $resArr[0];
-			$this->_latestContent = new LetoDMS_Core_DocumentContent($this, $resArr["version"], $resArr["comment"], $resArr["date"], $resArr["createdBy"], $resArr["dir"], $resArr["orgFileName"], $resArr["fileType"], $resArr["mimeType"]);
+			$this->_latestContent = new LetoDMS_Core_DocumentContent($resArr["id"], $this, $resArr["version"], $resArr["comment"], $resArr["date"], $resArr["createdBy"], $resArr["dir"], $resArr["orgFileName"], $resArr["fileType"], $resArr["mimeType"]);
 		}
 		return $this->_latestContent;
 	} /* }}} */
@@ -1256,6 +1249,10 @@ class LetoDMS_Core_Document { /* {{{ */
 		if (!$db->getResult($queryStr))
 			return false;
 
+		$queryStr = "DELETE FROM tblDocumentContentAttributes WHERE content = " . $version->getId();
+		if (!$db->getResult($queryStr))
+			return false;
+
 		$queryStr = "DELETE FROM `tblDocumentStatusLog` WHERE `statusID` = '".$stID."'";
 		if (!$db->getResult($queryStr))
 			return false;
@@ -1272,6 +1269,7 @@ class LetoDMS_Core_Document { /* {{{ */
 				$emailList[] = $st["required"];
 			}
 		}
+
 		if (strlen($stList)>0) {
 			$queryStr = "DELETE FROM `tblDocumentReviewLog` WHERE `tblDocumentReviewLog`.`reviewID` IN (".$stList.")";
 			if (!$db->getResult($queryStr))
@@ -1394,7 +1392,7 @@ class LetoDMS_Core_Document { /* {{{ */
 		$dir = $this->getDir();
 
 		$queryStr = "INSERT INTO tblDocumentFiles (comment, date, dir, document, fileType, mimeType, orgFileName, userID, name) VALUES ".
-			"(".$db->qstr($comment).", '".mktime()."', ".$db->qstr($dir).", ".$this->_id.", ".$db->qstr($fileType).", ".$db->qstr($mimeType).", ".$db->qstr($orgFileName).",".$user->getID().",".$db->qstr($name).")";
+			"(".$db->qstr($comment).", '".time()."', ".$db->qstr($dir).", ".$this->_id.", ".$db->qstr($fileType).", ".$db->qstr($mimeType).", ".$db->qstr($orgFileName).",".$user->getID().",".$db->qstr($name).")";
 		if (!$db->getResult($queryStr)) return false;
 
 		$id = $db->getInsertID();
@@ -1460,6 +1458,9 @@ class LetoDMS_Core_Document { /* {{{ */
 				return false;
 
 		$queryStr = "DELETE FROM tblDocuments WHERE id = " . $this->_id;
+		if (!$db->getResult($queryStr))
+			return false;
+		$queryStr = "DELETE FROM tblDocumentAttributes WHERE document = " . $this->_id;
 		if (!$db->getResult($queryStr))
 			return false;
 		$queryStr = "DELETE FROM tblACLs WHERE target = " . $this->_id . " AND targetType = " . T_DOCUMENT;
@@ -1490,7 +1491,6 @@ class LetoDMS_Core_Document { /* {{{ */
 		$db = $this->_dms->getDB();
 
 		if (!isset($this->_approversList)) {
-
 			$this->_approversList = array("groups" => array(), "users" => array());
 			$userIDs = "";
 			$groupIDs = "";
@@ -1658,9 +1658,9 @@ class LetoDMS_Core_Document { /* {{{ */
  * @copyright  Copyright (C) 2002-2005 Markus Westphal,
  *             2006-2008 Malcolm Cowe, 2010 Matteo Lucarelli,
  *             2010 Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
-class LetoDMS_Core_DocumentContent { /* {{{ */
+class LetoDMS_Core_DocumentContent extends LetoDMS_Core_Object { /* {{{ */
 
 	// if status is released and there are reviewers set status draft_rev
 	// if status is released or draft_rev and there are approves set status draft_app
@@ -1694,12 +1694,14 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 				}
 			}
 		}
+
 		if ($pendingReview) $this->setStatus(S_DRAFT_REV,"",$user);
 		else if ($pendingApproval) $this->setStatus(S_DRAFT_APP,"",$user);
 		else $this->setStatus(S_RELEASED,"",$user);
 	} /* }}} */
 
-	function LetoDMS_Core_DocumentContent($document, $version, $comment, $date, $userID, $dir, $orgFileName, $fileType, $mimeType) { /* {{{ */
+	function LetoDMS_Core_DocumentContent($id, $document, $version, $comment, $date, $userID, $dir, $orgFileName, $fileType, $mimeType) { /* {{{ */
+		parent::__construct($id);
 		$this->_document = $document;
 		$this->_version = (int) $version;
 		$this->_comment = $comment;
@@ -1709,6 +1711,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		$this->_orgFileName = $orgFileName;
 		$this->_fileType = $fileType;
 		$this->_mimeType = $mimeType;
+		$this->_dms = $document->_dms;
 	} /* }}} */
 
 	function getVersion() { return $this->_version; }
@@ -1719,11 +1722,14 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 	function getFileName(){ return "data" . $this->_fileType; }
 	function getDir() { return $this->_dir; }
 	function getMimeType() { return $this->_mimeType; }
+	function getDocument() { return $this->_document; }
+
 	function getUser() { /* {{{ */
 		if (!isset($this->_user))
 			$this->_user = $this->_document->_dms->getUser($this->_userID);
 		return $this->_user;
 	} /* }}} */
+
 	function getPath() { return $this->_document->getDir() . $this->_version . $this->_fileType; }
 
 	function setComment($newComment) { /* {{{ */
@@ -1890,7 +1896,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 			return false;
 		}
 		$queryStr = "INSERT INTO `tblDocumentStatusLog` (`statusID`, `status`, `comment`, `date`, `userID`) ".
-			"VALUES ('". $this->_status["statusID"] ."', '". (int) $status ."', ".$db->qstr($comment).", NOW(), '". $updateUser->getID() ."')";
+			"VALUES ('". $this->_status["statusID"] ."', '". (int) $status ."', ".$db->qstr($comment).", CURRENT_TIMESTAMP, '". $updateUser->getID() ."')";
 		$res = $db->getResult($queryStr);
 		if (is_bool($res) && !$res)
 			return false;
@@ -1924,7 +1930,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 			if($recs) {
 				foreach($recs as $rec) {
 					$queryStr=
-						"SELECT `tblDocumentReviewers`.*, `tblDocumentReviewLog`.`status`, ".
+						"SELECT `tblDocumentReviewers`.*, `tblDocumentReviewLog`.`reviewLogID`, `tblDocumentReviewLog`.`status`, ".
 						"`tblDocumentReviewLog`.`comment`, `tblDocumentReviewLog`.`date`, ".
 						"`tblDocumentReviewLog`.`userID`, `tblUsers`.`fullName`, `tblGroups`.`name` AS `groupName` ".
 						"FROM `tblDocumentReviewers` ".
@@ -2032,7 +2038,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		}
 
 		$queryStr = "INSERT INTO `tblDocumentReviewLog` (`reviewID`, `status`, `comment`, `date`, `userID`) ".
-			"VALUES ('". $reviewID ."', '0', '', NOW(), '". $requestUser->getID() ."')";
+			"VALUES ('". $reviewID ."', '0', '', CURRENT_TIMESTAMP, '". $requestUser->getID() ."')";
 		$res = $db->getResult($queryStr);
 		if (is_bool($res) && !$res) {
 			return -1;
@@ -2090,7 +2096,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		}
 
 		$queryStr = "INSERT INTO `tblDocumentReviewLog` (`reviewID`, `status`, `comment`, `date`, `userID`) ".
-			"VALUES ('". $reviewID ."', '0', '', NOW(), '". $requestUser->getID() ."')";
+			"VALUES ('". $reviewID ."', '0', '', CURRENT_TIMESTAMP, '". $requestUser->getID() ."')";
 		$res = $db->getResult($queryStr);
 		if (is_bool($res) && !$res) {
 			return -1;
@@ -2126,13 +2132,15 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		$queryStr = "INSERT INTO `tblDocumentReviewLog` (`reviewID`, `status`,
   	  `comment`, `date`, `userID`) ".
 			"VALUES ('". $reviewStatus["indstatus"][0]["reviewID"] ."', '".
-			(int) $status ."', ".$db->qstr($comment).", NOW(), '".
+			(int) $status ."', ".$db->qstr($comment).", CURRENT_TIMESTAMP, '".
 			$requestUser->getID() ."')";
 		$res=$db->getResult($queryStr);
 		if (is_bool($res) && !$res)
 			return -1;
-		else
-			return 0;
+		else {
+			$reviewLogID = $db->getInsertID();
+			return $reviewLogID;
+		}
  } /* }}} */
 
 	function setReviewByGrp($group, $requestUser, $status, $comment) { /* {{{ */
@@ -2160,13 +2168,15 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		$queryStr = "INSERT INTO `tblDocumentReviewLog` (`reviewID`, `status`,
   	  `comment`, `date`, `userID`) ".
 			"VALUES ('". $reviewStatus[0]["reviewID"] ."', '".
-			(int) $status ."', ".$db->qstr($comment).", NOW(), '".
+			(int) $status ."', ".$db->qstr($comment).", CURRENT_TIMESTAMP, '".
 			$requestUser->getID() ."')";
 		$res=$db->getResult($queryStr);
 		if (is_bool($res) && !$res)
 			return -1;
-		else
-			return 0;
+		else {
+			$reviewLogID = $db->getInsertID();
+			return $reviewLogID;
+		}
  } /* }}} */
 
 	function addIndApprover($user, $requestUser) { /* {{{ */
@@ -2215,13 +2225,14 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		}
 
 		$queryStr = "INSERT INTO `tblDocumentApproveLog` (`approveID`, `status`, `comment`, `date`, `userID`) ".
-			"VALUES ('". $approveID ."', '0', '', NOW(), '". $requestUser->getID() ."')";
+			"VALUES ('". $approveID ."', '0', '', CURRENT_TIMESTAMP, '". $requestUser->getID() ."')";
 		$res = $db->getResult($queryStr);
 		if (is_bool($res) && !$res) {
 			return -1;
 		}
 
-		return 0;
+		$approveLogID = $db->getInsertID();
+		return $approveLogID;
 	} /* }}} */
 
 	function addGrpApprover($group, $requestUser) { /* {{{ */
@@ -2270,7 +2281,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		}
 
 		$queryStr = "INSERT INTO `tblDocumentApproveLog` (`approveID`, `status`, `comment`, `date`, `userID`) ".
-			"VALUES ('". $approveID ."', '0', '', NOW(), '". $requestUser->getID() ."')";
+			"VALUES ('". $approveID ."', '0', '', CURRENT_TIMESTAMP, '". $requestUser->getID() ."')";
 		$res = $db->getResult($queryStr);
 		if (is_bool($res) && !$res) {
 			return -1;
@@ -2279,7 +2290,8 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		// Add approver to event notification table.
 		//$this->_document->addNotify($groupID, false);
 
-		return 0;
+		$approveLogID = $db->getInsertID();
+		return $approveLogID;
 	} /* }}} */
 
 	/**
@@ -2328,7 +2340,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		$queryStr = "INSERT INTO `tblDocumentApproveLog` (`approveID`, `status`,
   	  `comment`, `date`, `userID`) ".
 			"VALUES ('". $approvalStatus["indstatus"][0]["approveID"] ."', '".
-			(int) $status ."', ".$db->qstr($comment).", NOW(), '".
+			(int) $status ."', ".$db->qstr($comment).", CURRENT_TIMESTAMP, '".
 			$requestUser->getID() ."')";
 		$res=$db->getResult($queryStr);
 		if (is_bool($res) && !$res)
@@ -2368,7 +2380,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		$queryStr = "INSERT INTO `tblDocumentApproveLog` (`approveID`, `status`,
   	  `comment`, `date`, `userID`) ".
 			"VALUES ('". $approvalStatus[0]["approveID"] ."', '".
-			(int) $status ."', ".$db->qstr($comment).", NOW(), '".
+			(int) $status ."', ".$db->qstr($comment).", CURRENT_TIMESTAMP, '".
 			$requestUser->getID() ."')";
 		$res=$db->getResult($queryStr);
 		if (is_bool($res) && !$res)
@@ -2399,7 +2411,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		}
 
 		$queryStr = "INSERT INTO `tblDocumentReviewLog` (`reviewID`, `status`, `comment`, `date`, `userID`) ".
-			"VALUES ('". $reviewStatus["indstatus"][0]["reviewID"] ."', '-2', '', NOW(), '". $requestUser->getID() ."')";
+			"VALUES ('". $reviewStatus["indstatus"][0]["reviewID"] ."', '-2', '', CURRENT_TIMESTAMP, '". $requestUser->getID() ."')";
 		$res = $db->getResult($queryStr);
 		if (is_bool($res) && !$res) {
 			return -1;
@@ -2430,7 +2442,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		}
 
 		$queryStr = "INSERT INTO `tblDocumentReviewLog` (`reviewID`, `status`, `comment`, `date`, `userID`) ".
-			"VALUES ('". $reviewStatus[0]["reviewID"] ."', '-2', '', NOW(), '". $requestUser->getID() ."')";
+			"VALUES ('". $reviewStatus[0]["reviewID"] ."', '-2', '', CURRENT_TIMESTAMP, '". $requestUser->getID() ."')";
 		$res = $db->getResult($queryStr);
 		if (is_bool($res) && !$res) {
 			return -1;
@@ -2461,7 +2473,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		}
 
 		$queryStr = "INSERT INTO `tblDocumentApproveLog` (`approveID`, `status`, `comment`, `date`, `userID`) ".
-			"VALUES ('". $approvalStatus["indstatus"][0]["approveID"] ."', '-2', '', NOW(), '". $requestUser->getID() ."')";
+			"VALUES ('". $approvalStatus["indstatus"][0]["approveID"] ."', '-2', '', CURRENT_TIMESTAMP, '". $requestUser->getID() ."')";
 		$res = $db->getResult($queryStr);
 		if (is_bool($res) && !$res) {
 			return -1;
@@ -2492,7 +2504,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
 		}
 
 		$queryStr = "INSERT INTO `tblDocumentApproveLog` (`approveID`, `status`, `comment`, `date`, `userID`) ".
-			"VALUES ('". $approvalStatus[0]["approveID"] ."', '-2', '', NOW(), '". $requestUser->getID() ."')";
+			"VALUES ('". $approvalStatus[0]["approveID"] ."', '-2', '', CURRENT_TIMESTAMP, '". $requestUser->getID() ."')";
 		$res = $db->getResult($queryStr);
 		if (is_bool($res) && !$res) {
 			return -1;
@@ -2519,7 +2531,7 @@ class LetoDMS_Core_DocumentContent { /* {{{ */
  * @copyright  Copyright (C) 2002-2005 Markus Westphal,
  *             2006-2008 Malcolm Cowe, 2010 Matteo Lucarelli,
  *             2010 Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
 class LetoDMS_Core_DocumentLink { /* {{{ */
 	var $_id;
@@ -2571,7 +2583,7 @@ class LetoDMS_Core_DocumentLink { /* {{{ */
  * @copyright  Copyright (C) 2002-2005 Markus Westphal,
  *             2006-2008 Malcolm Cowe, 2010 Matteo Lucarelli,
  *             2010 Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
 class LetoDMS_Core_DocumentFile { /* {{{ */
 	var $_id;
@@ -2637,7 +2649,7 @@ class LetoDMS_Core_DocumentFile { /* {{{ */
  * @copyright  Copyright (C) 2002-2005 Markus Westphal,
  *             2006-2008 Malcolm Cowe, 2010 Matteo Lucarelli,
  *             2010 Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
 class LetoDMS_Core_AddContentResultSet { /* {{{ */
 
