@@ -9,7 +9,7 @@
  *             Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Matteo Lucarelli, 2010 Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
 
 /**
@@ -25,14 +25,9 @@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Matteo Lucarelli, 2010 Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
-class LetoDMS_Core_Folder {
-	/**
-	 * @var integer unique id of folder
-	 */
-	var $_id;
-
+class LetoDMS_Core_Folder extends LetoDMS_Core_Object {
 	/**
 	 * @var string name of folder
 	 */
@@ -73,12 +68,8 @@ class LetoDMS_Core_Folder {
 	 */
 	var $_sequence;
 
-	/**
-	 * @var object back reference to document management system
-	 */
-	var $_dms;
-
 	function LetoDMS_Core_Folder($id, $name, $parentID, $comment, $date, $ownerID, $inheritAccess, $defaultAccess, $sequence) { /* {{{ */
+		parent::__construct($id);
 		$this->_id = $id;
 		$this->_name = $name;
 		$this->_parentID = $parentID;
@@ -89,20 +80,6 @@ class LetoDMS_Core_Folder {
 		$this->_defaultAccess = $defaultAccess;
 		$this->_sequence = $sequence;
 		$this->_notifyList = array();
-		$this->_dms = null;
-	} /* }}} */
-
-	/*
-	 * Set dms this folder belongs to.
-	 *
-	 * Each folder needs a reference to the dms it belongs to. It will be
-	 * set when the folder is created by LetoDMS::getFolder(). The dms has a
-	 * references to the currently logged in user and the database connection.
-	 *
-	 * @param object $dms reference to dms
-	 */
-	function setDMS($dms) { /* {{{ */
-		$this->_dms = $dms;
 	} /* }}} */
 
 	/*
@@ -370,7 +347,19 @@ class LetoDMS_Core_Folder {
 		return $this->_subFolders;
 	} /* }}} */
 
-	function addSubFolder($name, $comment, $owner, $sequence) { /* {{{ */
+	/**
+	 * Add a new subfolder
+	 *
+	 * @param string $name name of folder
+	 * @param string $comment comment of folder
+	 * @param object $owner owner of folder
+	 * @param integer $sequence position of folder in list of sub folders.
+	 * @param array $attributes list of document attributes. The element key
+	 *        must be the id of the attribute definition.
+	 * @return object object of type LetoDMS_Core_Folder or false in case of
+	 *         an error.
+	 */
+	function addSubFolder($name, $comment, $owner, $sequence, $attributes) { /* {{{ */
 		$db = $this->_dms->getDB();
 
 		// Set the folderList of the folder
@@ -384,12 +373,22 @@ class LetoDMS_Core_Folder {
 		}
 		//inheritAccess = true, defaultAccess = M_READ
 		$queryStr = "INSERT INTO tblFolders (name, parent, folderList, comment, date, owner, inheritAccess, defaultAccess, sequence) ".
-					"VALUES (".$db->qstr($name).", ".$this->_id.", ".$db->qstr($pathPrefix).", ".$db->qstr($comment).", ".mktime().", ".$owner->getID().", 1, ".M_READ.", ". $sequence.")";
+					"VALUES (".$db->qstr($name).", ".$this->_id.", ".$db->qstr($pathPrefix).", ".$db->qstr($comment).", ".time().", ".$owner->getID().", 1, ".M_READ.", ". $sequence.")";
 		if (!$db->getResult($queryStr))
 			return false;
 		$newFolder = $this->_dms->getFolder($db->getInsertID());
 		unset($this->_subFolders);
 
+		if($attributes) {
+			foreach($attributes as $attrdefid=>$attribute) {
+				if(trim($attribute))
+					if(!$newFolder->setAttributeValue($this->_dms->getAttributeDefinition($attrdefid), $attribute)) {
+						$newFolder->remove();
+						return false;
+					}
+			}
+		}
+
 		return $newFolder;
 	} /* }}} */
 
@@ -503,11 +502,15 @@ class LetoDMS_Core_Folder {
 	 * @param string $reqversion version number of the content
 	 * @param string $version_comment comment of the content. If left empty
 	 *        the $comment will be used.
+	 * @param array $attributes list of document attributes. The element key
+	 *        must be the id of the attribute definition.
+	 * @param array $version_attributes list of document version attributes.
+	 *        The element key must be the id of the attribute definition.
 	 * @return array/boolean false in case of error, otherwise an array
 	 *        containing two elements. The first one is the new document, the
 	 *        second one is the result set returned when inserting the content.
 	 */
-	function addDocument($name, $comment, $expires, $owner, $keywords, $categories, $tmpFile, $orgFileName, $fileType, $mimeType, $sequence, $reviewers=array(), $approvers=array(),$reqversion,$version_comment="") { /* {{{ */
+	function addDocument($name, $comment, $expires, $owner, $keywords, $categories, $tmpFile, $orgFileName, $fileType, $mimeType, $sequence, $reviewers=array(), $approvers=array(),$reqversion,$version_comment="", $attributes=array(), $version_attributes=array()) { /* {{{ */
 		$db = $this->_dms->getDB();
 
 		$expires = (!$expires) ? 0 : $expires;
@@ -523,15 +526,15 @@ class LetoDMS_Core_Folder {
 		}
 
 		$queryStr = "INSERT INTO tblDocuments (name, comment, date, expires, owner, folder, folderList, inheritAccess, defaultAccess, locked, keywords, sequence) VALUES ".
-					"(".$db->qstr($name).", ".$db->qstr($comment).", " . mktime().", ".(int) $expires.", ".$owner->getID().", ".$this->_id.",".$db->qstr($pathPrefix).", 1, ".M_READ.", -1, ".$db->qstr($keywords).", " . $sequence . ")";
+					"(".$db->qstr($name).", ".$db->qstr($comment).", " . time().", ".(int) $expires.", ".$owner->getID().", ".$this->_id.",".$db->qstr($pathPrefix).", 1, ".M_READ.", -1, ".$db->qstr($keywords).", " . $sequence . ")";
 		if (!$db->getResult($queryStr))
 			return false;
 
 		$document = $this->_dms->getDocument($db->getInsertID());
 
 		if ($version_comment!="")
-			$res = $document->addContent($version_comment, $owner, $tmpFile, $orgFileName, $fileType, $mimeType, $reviewers, $approvers,$reqversion);
-		else $res = $document->addContent($comment, $owner, $tmpFile, $orgFileName, $fileType, $mimeType, $reviewers, $approvers,$reqversion);
+			$res = $document->addContent($version_comment, $owner, $tmpFile, $orgFileName, $fileType, $mimeType, $reviewers, $approvers,$reqversion, $version_attributes);
+		else $res = $document->addContent($comment, $owner, $tmpFile, $orgFileName, $fileType, $mimeType, $reviewers, $approvers,$reqversion, $version_attributes);
 
 		if (is_bool($res) && !$res) {
 			$queryStr = "DELETE FROM tblDocuments WHERE id = " . $document->getID();
@@ -542,6 +545,17 @@ class LetoDMS_Core_Folder {
 		if($categories) {
 			$document->setCategories($categories);
 		}
+
+		if($attributes) {
+			foreach($attributes as $attrdefid=>$attribute) {
+				if(trim($attribute))
+					if(!$document->setAttributeValue($this->_dms->getAttributeDefinition($attrdefid), $attribute)) {
+						$document->remove();
+						return false;
+					}
+			}
+		}
+
 		return array($document, $res);
 	} /* }}} */
 
@@ -560,17 +574,20 @@ class LetoDMS_Core_Folder {
 		if (is_bool($res) && !$res) return false;
 
 		foreach ($this->_subFolders as $subFolder) {
-			$res = $subFolder->remove(FALSE);
+			$res = $subFolder->remove();
 			if (!$res) return false;
 		}
 
 		foreach ($this->_documents as $document) {
-			$res = $document->remove(FALSE);
+			$res = $document->remove();
 			if (!$res) return false;
 		}
 
 		//Entfernen der Datenbankeintrge
 		$queryStr = "DELETE FROM tblFolders WHERE id =  " . $this->_id;
+		if (!$db->getResult($queryStr))
+			return false;
+		$queryStr = "DELETE FROM tblFolderAttributes WHERE folder =  " . $this->_id;
 		if (!$db->getResult($queryStr))
 			return false;
 		$queryStr = "DELETE FROM tblACLs WHERE target = ". $this->_id. " AND targetType = " . T_FOLDER;
@@ -587,7 +604,7 @@ class LetoDMS_Core_Folder {
 	/**
 	 * Returns a list of access privileges
 	 *
-	 * If the document inherits the access privileges from the parent folder
+	 * If the folder inherits the access privileges from the parent folder
 	 * those will be returned.
 	 * $mode and $op can be set to restrict the list of returned access
 	 * privileges. If $mode is set to M_ANY no restriction will apply
@@ -755,6 +772,9 @@ class LetoDMS_Core_Folder {
 	 * @return integer access mode
 	 */
 	function getAccessMode($user) { /* {{{ */
+		if(!$user)
+			return M_NONE;
+
 		/* Admins have full access */
 		if ($user->isAdmin()) return M_ALL;
 
