@@ -9,7 +9,7 @@
  * @author     Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
 
 /**
@@ -20,7 +20,7 @@
  * @author     Markus Westphal, Malcolm Cowe, Uwe Steinmann <uwe@steinmann.cx>
  * @copyright  Copyright (C) 2002-2005 Markus Westphal, 2006-2008 Malcolm Cowe,
  *             2010 Uwe Steinmann
- * @version    Release: 3.3.9
+ * @version    Release: 3.4.2
  */
 class LetoDMS_Core_User {
 	/**
@@ -44,6 +44,13 @@ class LetoDMS_Core_User {
 	 */
 	var $_pwd;
 
+	/**
+	 * @var string date when password expires
+	 *
+	 * @access protected
+	 */
+	var $_pwdExpiration;
+
 	/**
 	 * @var string full human readable name of user
 	 *
@@ -91,12 +98,26 @@ class LetoDMS_Core_User {
 	var $_role;
 
 	/**
-	 * @var string true if user shall be hidden
+	 * @var boolean true if user shall be hidden
 	 *
 	 * @access protected
 	 */
 	var $_isHidden;
 
+	/**
+	 * @var boolean true if user is disabled
+	 *
+	 * @access protected
+	 */
+	var $_isDisabled;
+
+	/**
+	 * @var int number of login failures
+	 *
+	 * @access protected
+	 */
+	var $_loginFailures;
+
 	/**
 	 * @var object reference to the dms instance this user belongs to
 	 *
@@ -108,7 +129,7 @@ class LetoDMS_Core_User {
 	const role_admin = '1';
 	const role_guest = '2';
 
-	function LetoDMS_Core_User($id, $login, $pwd, $fullName, $email, $language, $theme, $comment, $role, $isHidden=0) {
+	function LetoDMS_Core_User($id, $login, $pwd, $fullName, $email, $language, $theme, $comment, $role, $isHidden=0, $isDisabled=0, $pwdExpiration='', $loginFailures=0) {
 		$this->_id = $id;
 		$this->_login = $login;
 		$this->_pwd = $pwd;
@@ -119,6 +140,9 @@ class LetoDMS_Core_User {
 		$this->_comment = $comment;
 		$this->_role = $role;
 		$this->_isHidden = $isHidden;
+		$this->_isDisabled = $isDisabled;
+		$this->_pwdExpiration = $pwdExpiration;
+		$this->_loginFailures = $loginFailures;
 		$this->_dms = null;
 	}
 
@@ -170,6 +194,20 @@ class LetoDMS_Core_User {
 		return true;
 	} /* }}} */
 
+	function getPwdExpiration() { return $this->_pwdExpiration; }
+
+	function setPwdExpiration($newPwdExpiration) { /* {{{ */
+		$db = $this->_dms->getDB();
+
+		$queryStr = "UPDATE tblUsers SET pwdExpiration =".$db->qstr($newPwdExpiration)." WHERE id = " . $this->_id;
+		$res = $db->getResult($queryStr);
+		if (!$res)
+			return false;
+
+		$this->_pwdExpiration = $newPwdExpiration;
+		return true;
+	} /* }}} */
+
 	function getEmail() { return $this->_email; }
 
 	function setEmail($newEmail) { /* {{{ */
@@ -279,13 +317,49 @@ class LetoDMS_Core_User {
 		return true;
 	}	 /* }}} */
 
+	function isDisabled() { return $this->_isDisabled; }
+
+	function setDisabled($isDisabled) { /* {{{ */
+		$db = $this->_dms->getDB();
+
+		$isDisabled = ($isDisabled) ? "1" : "0";
+		$queryStr = "UPDATE tblUsers SET disabled = " . $isDisabled . " WHERE id = " . $this->_id;
+		if (!$db->getResult($queryStr))
+			return false;
+
+		$this->_isDisabled = $isDisabled;
+		return true;
+	}	 /* }}} */
+
+	function addLoginFailure() { /* {{{ */
+		$db = $this->_dms->getDB();
+
+		$this->_loginFailures++;
+		$queryStr = "UPDATE tblUsers SET loginfailures = " . $this->_loginFailures . " WHERE id = " . $this->_id;
+		if (!$db->getResult($queryStr))
+			return false;
+
+		return $this->_loginFailures;
+	} /* }}} */
+
+	function clearLoginFailures() { /* {{{ */
+		$db = $this->_dms->getDB();
+
+		$this->_loginFailures = 0;
+		$queryStr = "UPDATE tblUsers SET loginfailures = " . $this->_loginFailures . " WHERE id = " . $this->_id;
+		if (!$db->getResult($queryStr))
+			return false;
+
+		return true;
+	} /* }}} */
+
 	/**
 	 * Remove the user and also remove all its keywords, notifies, etc.
 	 * Do not remove folders and documents of the user, but assign them
 	 * to a different user.
 	 *
 	 * @param object $user the user doing the removal (needed for entry in
-	 *        review log.
+	 *        review and approve log).
 	 * @param object $assignToUser the user who is new owner of folders and
 	 *        documents which previously were owned by the delete user.
 	 * @return boolean true on success or false in case of an error
@@ -360,8 +434,12 @@ class LetoDMS_Core_User {
 		$queryStr = "DELETE FROM tblUserImages WHERE userID = " . $this->_id;
 		if (!$db->getResult($queryStr)) return false;
 
-		// Delete user itself
-		$queryStr = "DELETE FROM tblUsers WHERE id = " . $this->_id;
+		// Delete entries in password history
+		$queryStr = "DELETE FROM tblUserPasswordHistory WHERE userID = " . $this->_id;
+		if (!$db->getResult($queryStr)) return false;
+
+		// Delete entries in password request
+		$queryStr = "DELETE FROM tblUserPasswordRequest WHERE userID = " . $this->_id;
 		if (!$db->getResult($queryStr)) return false;
 
 		// mandatory review/approve
@@ -381,6 +459,10 @@ class LetoDMS_Core_User {
 		$queryStr = "UPDATE tblEvents SET userID = " . $assignTo . " WHERE userID = " . $this->_id;
 		if (!$db->getResult($queryStr)) return false;
 
+		// Delete user itself
+		$queryStr = "DELETE FROM tblUsers WHERE id = " . $this->_id;
+		if (!$db->getResult($queryStr)) return false;
+
 
 		// TODO : update document status if reviewer/approver has been deleted
 		// "DELETE FROM tblDocumentApproveLog WHERE userID = " . $this->_id;
@@ -465,6 +547,7 @@ class LetoDMS_Core_User {
 			$this->_groups = array();
 			foreach ($resArr as $row) {
 				$group = new LetoDMS_Core_Group($row["id"], $row["name"], $row["comment"]);
+				$group->setDMS($this->_dms);
 				array_push($this->_groups, $group);
 			}
 		}
@@ -548,7 +631,7 @@ class LetoDMS_Core_User {
 	 * further.
 	 *
 	 * For a detaile description of the result array see
-	 * {link LetoDMS_User::getApprovalStatus}
+	 * {link LetoDMS_Core_User::getApprovalStatus}
 	 *
 	 * @param int $documentID optional document id for which to retrieve the
 	 *        reviews
@@ -575,13 +658,20 @@ class LetoDMS_Core_User {
 			($documentID==null ? "" : "AND `tblDocumentReviewers`.`documentID` = '". (int) $documentID ."' ").
 			($version==null ? "" : "AND `tblDocumentReviewers`.`version` = '". (int) $version ."' ").
 			"AND `tblDocumentReviewers`.`required`='". $this->_id ."' ".
-			"ORDER BY `tblDocumentReviewLog`.`reviewLogID` DESC LIMIT 1";
+			"ORDER BY `tblDocumentReviewLog`.`reviewLogID` DESC";
 		$resArr = $db->getResultArray($queryStr);
 		if (is_bool($resArr) && $resArr == false)
 			return false;
 		if (count($resArr)>0) {
-			foreach ($resArr as $res)
-				$status["indstatus"][] = $res;
+			foreach ($resArr as $res) {
+				if(isset($status["indstatus"][$res['documentID']])) {
+					if($status["indstatus"][$res['documentID']]['date'] < $res['date']) {
+						$status["indstatus"][$res['documentID']] = $res;
+					}
+				} else {
+					$status["indstatus"][$res['documentID']] = $res;
+				}
+			}
 		}
 
 		// See if the user is the member of a group that has been assigned to
@@ -596,13 +686,20 @@ class LetoDMS_Core_User {
 			($documentID==null ? "" : "AND `tblDocumentReviewers`.`documentID` = '". (int) $documentID ."' ").
 			($version==null ? "" : "AND `tblDocumentReviewers`.`version` = '". (int) $version ."' ").
 			"AND `tblGroupMembers`.`userID`='". $this->_id ."' ".
-			"ORDER BY `tblDocumentReviewLog`.`reviewLogID` DESC LIMIT 1";
+			"ORDER BY `tblDocumentReviewLog`.`reviewLogID` DESC";
 		$resArr = $db->getResultArray($queryStr);
 		if (is_bool($resArr) && $resArr == false)
 			return false;
 		if (count($resArr)>0) {
-			foreach ($resArr as $res)
-				$status["grpstatus"][] = $res;
+			foreach ($resArr as $res) {
+				if(isset($status["grpstatus"][$res['documentID']])) {
+					if($status["grpstatus"][$res['documentID']]['date'] < $res['date']) {
+						$status["grpstatus"][$res['documentID']] = $res;
+					}
+				} else {
+					$status["grpstatus"][$res['documentID']] = $res;
+				}
+			}
 		}
 		return $status;
 	} /* }}} */
@@ -669,14 +766,21 @@ class LetoDMS_Core_User {
 			($documentID==null ? "" : "AND `tblDocumentApprovers`.`documentID` = '". (int) $documentID ."' ").
 			($version==null ? "" : "AND `tblDocumentApprovers`.`version` = '". (int) $version ."' ").
 			"AND `tblDocumentApprovers`.`required`='". $this->_id ."' ".
-			"ORDER BY `tblDocumentApproveLog`.`approveLogID` DESC LIMIT 1";
+			"ORDER BY `tblDocumentApproveLog`.`approveLogID` DESC";
 
 		$resArr = $db->getResultArray($queryStr);
 		if (is_bool($resArr) && $resArr == false)
 			return false;
 		if (count($resArr)>0) {
-			foreach ($resArr as $res)
-				$status["indstatus"][] = $res;
+			foreach ($resArr as $res) {
+				if(isset($status["indstatus"][$res['documentID']])) {
+					if($status["indstatus"][$res['documentID']]['date'] < $res['date']) {
+						$status["indstatus"][$res['documentID']] = $res;
+					}
+				} else {
+					$status["indstatus"][$res['documentID']] = $res;
+				}
+			}
 		}
 
 		// See if the user is the member of a group that has been assigned to
@@ -706,13 +810,20 @@ class LetoDMS_Core_User {
 			($documentID==null ? "" : "AND `tblDocumentApprovers`.`documentID` = '". (int) $documentID ."' ").
 			($version==null ? "" : "AND `tblDocumentApprovers`.`version` = '". (int) $version ."' ").
 			"AND `tblGroupMembers`.`userID`='". $this->_id ."' ".
-			"ORDER BY `tblDocumentApproveLog`.`approveLogID` DESC LIMIT 1";
+			"ORDER BY `tblDocumentApproveLog`.`approveLogID` DESC";
 		$resArr = $db->getResultArray($queryStr);
 		if (is_bool($resArr) && $resArr == false)
 			return false;
 		if (count($resArr)>0) {
-			foreach ($resArr as $res)
-				$status["grpstatus"][] = $res;
+			foreach ($resArr as $res) {
+				if(isset($status["grpstatus"][$res['documentID']])) {
+					if($status["grpstatus"][$res['documentID']]['date'] < $res['date']) {
+						$status["grpstatus"][$res['documentID']] = $res;
+					}
+				} else {
+					$status["grpstatus"][$res['documentID']] = $res;
+				}
+			}
 		}
 		return $status;
 	} /* }}} */
@@ -738,7 +849,7 @@ class LetoDMS_Core_User {
 
 	/**
 	 * Get a list of mandatory approvers
-	 * See {link LetoDMS_User::getMandatoryReviewers}
+	 * See {link LetoDMS_Core_User::getMandatoryReviewers}
 	 *
 	 * @return array list of arrays with two elements containing the user id
 	 *         (approverUserID) and group id (approverGroupID) of the approver.
